%global binver 2.99
%global interface_age 0
%global gettext_version 30
%global lib_api_version %{major}.99
%global unstable_so_version 3.0
%global lib_micro %micro

Summary:        GNU Image Manipulation Program
Name:           gimp
Version:        2.99.8
Release:        2%{?dist}

%global major %(ver=%{version}; echo ${ver%%%%.*})
%global minor %(ver=%{version}; ver=${ver#%major.}; echo ${ver%%%%.*})
%global micro %(ver=%{version}; ver=${ver#%major.%minor.}; echo ${ver%%%%.*})
%global lib_minor %(echo $[%minor * 100])

License:        GPLv3+ and GPLv3
URL:            http://www.gimp.org/
Source0:        http://download.gimp.org/pub/gimp/v%{binver}/gimp-%{version}.tar.bz2

Patch0001:      gimp-CVE-2022-30067.patch
Patch0002:      gimp-CVE-2022-32990.patch
Patch3000:      gimp-2.10.12-default-font.patch
Patch3001:      gimp-remove-lua.patch

BuildRequires:  gcc glib2-devel make pkgconfig
BuildRequires:  alsa-lib-devel atk-devel babl-devel bzip2-devel cairo-devel fontconfig-devel freetype-devel
BuildRequires:  gdk-pixbuf2-devel gegl04-tools gegl04-devel libgs-devel gtk3-devel gtk-doc harfbuzz-devel
BuildRequires:  iso-codes-devel jasper-devel lcms2-devel libappstream-glib libappstream-glib-devel libarchive
BuildRequires:  libgexiv2-devel libgudev1-devel libjpeg-devel libmng-devel libpng-devel librsvg2-devel
BuildRequires:  libtiff-devel libwebp-devel libwmf-devel libmypaint-devel mypaint-brushes-devel
BuildRequires:  OpenEXR-devel openjpeg2-devel pango-devel perl poppler-glib-devel poppler-data-devel
BuildRequires:  python3-cairo-devel python3-gobject-devel python3-devel chrpath intltool gettext vala
BuildRequires:  xz-devel zlib-devel libX11-devel libXmu-devel libXpm-devel
Requires:       babl gegl04 fontconfig freetype glib2 gtk3 hicolor-icon-theme lcms2 pango xdg-utils
Requires:       %{name}-libs = %{version}-%{release}
Recommends:     mypaint-brushes


%description
GIMP (GNU Image Manipulation Program) is a powerful image composition and
editing program, which can be extremely useful for creating logos and other
graphics for web pages. GIMP has many of the tools and filters you would expect
to find in similar commercial offerings, and some interesting extras as well.
GIMP provides a large image manipulation toolbox, including channel operations
and layers, effects, sub-pixel imaging and anti-aliasing, and conversions, all
with multi-level undo.

%package libs
Summary:        GIMP libraries
License:        LGPLv3+

%description libs
The %{name}-libs package contains shared libraries needed for the GNU Image
Manipulation Program (GIMP).

%package devel
Summary:        GIMP plugin and extension development kit
License:        LGPLv3+
Requires:       %{name}-libs = %{version}-%{release}
Requires:       %{name}-devel-tools = %{version}-%{release}
Requires:       glib2-devel
Requires:       pkgconfig
Requires:       rpm >= 4.11.0

%description devel
The %{name}-devel package contains the static libraries and header files
for writing GNU Image Manipulation Program (GIMP) plug-ins and
extensions.

%package devel-tools
Summary:        GIMP plugin and extension development tools
License:        LGPLv3+
Requires:       %{name}-devel = %{version}-%{release}

%description devel-tools
The %{name}-devel-tools package contains gimptool, a helper program to
build GNU Image Manipulation Program (GIMP) plug-ins and extensions.


%prep
%autosetup -n gimp-%{version} -p1


%build
%configure \
    --with-python \
    --enable-mp \
    --disable-static \
    --with-print \
    --enable-gimp-console \
    --without-aa \
    --with-gudev \
    --with-linux-input \
    --without-webkit \
    --with-webp \
    --enable-default-binary=yes \
    --with-libmng --with-libxpm --with-alsa --with-cairo-pdf \
    --without-appdata-test \
    --with-bug-report-url=https://bugs.opencloudos.tech/

%make_build

cat << EOF > macros.gimp
# RPM macros for GIMP

%%_gimp_datadir %{_datadir}/gimp/2.99
%%_gimp_libdir %{_libdir}/gimp/2.99
%%_gimp_sysconfdir %{_sysconfdir}/gimp/2.99
%%_gimp_localedir %{_datadir}/locale
%%_gimp_scriptdir %{_datadir}/gimp/2.99/scripts
%%_gimp_plugindir %{_libdir}/gimp/2.99/plug-ins
EOF


%install
%make_install
install -D -m0644 macros.gimp %{buildroot}%{_rpmconfigdir}/macros.d/macros.gimp

find %{buildroot} -type f -print0 | xargs -0 -L 20 chrpath --delete --keepgoing 2>/dev/null || :
find %{buildroot} -name \*.la -delete

%py_byte_compile %{__python3} %{buildroot}%{_libdir}/gimp/%{lib_api_version}
find %{buildroot}%{_libdir}/gimp/%{lib_api_version} -type f | sed "s@^%{buildroot}@@g" | grep -v '\.a$' > gimp-plugin-files
find %{buildroot}%{_libdir}/gimp/%{lib_api_version}/* -type d | sed "s@^%{buildroot}@%%dir @g" >> gimp-plugin-files

ln -snf gimp-%{binver} %{buildroot}%{_bindir}/gimp
ln -snf gimp-%{binver}.1 %{buildroot}%{_mandir}/man1/gimp.1
ln -snf gimp-console-%{binver} %{buildroot}/%{_bindir}/gimp-console
ln -snf gimp-console-%{binver}.1 %{buildroot}/%{_mandir}/man1/gimp-console.1
ln -snf gimptool-%{lib_api_version} %{buildroot}%{_bindir}/gimptool
ln -snf gimptool-%{lib_api_version}.1 %{buildroot}%{_mandir}/man1/gimptool.1
ln -snf gimprc-%{binver}.5 %{buildroot}/%{_mandir}/man5/gimprc.5

grep -E -rl '^#!\s*/usr/bin/env\s+python' --include=\*.py "%{buildroot}" |
    while read file; do
        sed -r '1s,^#!\s*/usr/bin/env\s+python$,#!%{__python3},' -i "$file"
        sed -r '1s,^#!\s*/usr/bin/env\s+python3$,#!%{__python3},' -i "$file"
    done

echo "%{__python3}=%{__python3}" >> %{buildroot}%{_libdir}/gimp/%{lib_api_version}/interpreters/pygimp.interp

%find_lang gimp%{gettext_version}

%find_lang gimp%{gettext_version}-std-plug-ins

%find_lang gimp%{gettext_version}-script-fu

%find_lang gimp%{gettext_version}-libgimp

%find_lang gimp%{gettext_version}-python

cat gimp%{gettext_version}.lang gimp%{gettext_version}-std-plug-ins.lang gimp%{gettext_version}-script-fu.lang gimp%{gettext_version}-libgimp.lang gimp%{gettext_version}-python.lang > gimp-all.lang
cat gimp-plugin-files gimp-all.lang > gimp.files


%check
%make_build check


%files -f gimp.files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%doc docs/*.xcf*
%{_bindir}/gimp-%{binver}
%{_bindir}/gimp-console-%{binver}
%{_bindir}/gimp
%{_bindir}/gimp-console
%{_bindir}/gimp-test-clipboard-%{lib_api_version}
%{_datadir}/applications/*.desktop
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/metainfo/*.metainfo.xml
%dir %{_datadir}/gimp
%dir %{_datadir}/gimp/%{lib_api_version}
%{_datadir}/gimp/%{lib_api_version}/dynamics/
%{_datadir}/gimp/%{lib_api_version}/file-raw/
%{_datadir}/gimp/%{lib_api_version}/menus/
%{_datadir}/gimp/%{lib_api_version}/tags/
%{_datadir}/gimp/%{lib_api_version}/tips/
%{_datadir}/gimp/%{lib_api_version}/tool-presets/
%{_datadir}/gimp/%{lib_api_version}/ui/
%{_datadir}/gimp/%{lib_api_version}/brushes/
%{_datadir}/gimp/%{lib_api_version}/fractalexplorer/
%{_datadir}/gimp/%{lib_api_version}/gfig/
%{_datadir}/gimp/%{lib_api_version}/gflare/
%{_datadir}/gimp/%{lib_api_version}/gimpressionist/
%{_datadir}/gimp/%{lib_api_version}/gradients/
%{_datadir}/gimp/%{lib_api_version}/icons/
%{_datadir}/gimp/%{lib_api_version}/images/
%{_datadir}/gimp/%{lib_api_version}/palettes/
%{_datadir}/gimp/%{lib_api_version}/patterns/
%{_datadir}/gimp/%{lib_api_version}/scripts/
%{_datadir}/gimp/%{lib_api_version}/themes/
%{_datadir}/gimp/%{lib_api_version}/gimp-release
%{_datadir}/icons/hicolor/*/apps/gimp.*
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/%{lib_api_version}
%{_libexecdir}/gimp-debug-tool-%{lib_api_version}
%dir %{_sysconfdir}/gimp
%dir %{_sysconfdir}/gimp/%{lib_api_version}
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/controllerrc
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/gimprc
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/unitrc
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/sessionrc
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/templaterc
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/menurc
%config(noreplace) %{_sysconfdir}/gimp/%{lib_api_version}/toolrc
%{_sysconfdir}/gimp/%{lib_api_version}/gimp.css
%{_mandir}/man1/gimp-%{binver}.1*
%{_mandir}/man1/gimp-console-%{binver}.1*
%{_mandir}/man5/gimprc-%{binver}.5*
%{_mandir}/man1/gimp.1*
%{_mandir}/man1/gimp-console.1*
%{_mandir}/man5/gimprc.5*

%files libs
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/libgimp-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimp-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpbase-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpbase-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpcolor-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpcolor-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpconfig-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpconfig-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpmath-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpmath-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpmodule-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpmodule-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpthumb-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpthumb-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpui-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpui-%{unstable_so_version}.so.%{interface_age}
%{_libdir}/libgimpwidgets-%{unstable_so_version}.so.%{interface_age}.%{lib_minor}.%{lib_micro}
%{_libdir}/libgimpwidgets-%{unstable_so_version}.so.%{interface_age}

%files devel
%doc HACKING README.i18n
%doc %{_datadir}/gtk-doc
%{_datadir}/aclocal/*.m4
%{_datadir}/vala/*
%{_datadir}/gir-1.0/*
%{_includedir}/gimp-%{unstable_so_version}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_libdir}/girepository-1.0/*
%{_rpmconfigdir}/macros.d/macros.gimp

%files devel-tools
%{_bindir}/gimptool
%{_bindir}/gimptool-%{lib_api_version}
%{_mandir}/man1/gimptool.1*
%{_mandir}/man1/gimptool-%{lib_api_version}.1*


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.99.8-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 Miaojun Dong <zoedong@tencent.com> - 2.99.8-1
- initial build
